{
    "$graph": [
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "listing": [
                        "$(inputs.input_file)"
                    ],
                    "class": "InitialWorkDirRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "dockerPull": "dukegcb/samtools:1.3",
                    "class": "DockerRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "doc": "Aligned file to be sorted with samtools",
                    "id": "#samtools-index.cwl/input_file"
                }
            ],
            "baseCommand": [
                "samtools",
                "index"
            ],
            "arguments": [
                {
                    "valueFrom": "$(inputs.input_file.basename + '.bai')",
                    "position": 2
                }
            ],
            "id": "#samtools-index.cwl",
            "outputs": [
                {
                    "doc": "Indexed BAM file",
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.input_file.basename)"
                    },
                    "secondaryFiles": ".bai",
                    "id": "#samtools-index.cwl/indexed_file"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "doc": "Description: filters BAM file(s).\n\n\nUsage: bamtools filter [-in <filename> -in <filename> ... | -list <filelist>] [-out <filename> | [-forceCompression]] [-region <REGION>] [ [-script <filename] | [filterOptions] ]\n\n\nInput & Output:\n\n  -in <BAM filename>                the input BAM file(s) [stdin]\n\n  -list <filename>                  the input BAM file list, one\n\n                                    line per file\n\n  -out <BAM filename>               the output BAM file [stdout]\n\n  -region <REGION>                  only read data from this\n\n                                    genomic region (see documentation for more\n\n                                    details)\n\n  -script <filename>                the filter script file (see\n\n                                    documentation for more details)\n\n  -forceCompression                 if results are sent to stdout\n\n                                    (like when piping to another tool),\n\n                                    default behavior is to leave output\n\n                                    uncompressed. Use this flag to override\n\n                                    and force compression\n\n\n\nGeneral Filters:\n\n  -alignmentFlag <int>              keep reads with this *exact*\n\n                                    alignment flag (for more detailed queries,\n\n                                    see below)\n\n  -insertSize <int>                 keep reads with insert size\n\n                                    that matches pattern\n\n  -mapQuality <[0-255]>             keep reads with map quality\n\n                                    that matches pattern\n\n  -name <string>                    keep reads with name that\n\n                                    matches pattern\n\n  -queryBases <string>              keep reads with motif that\n\n                                    matches pattern\n\n  -tag <TAG:VALUE>                  keep reads with this\n\n                                    key=>value pair\n\n\n\nAlignment Flag Filters:\n\n  -isDuplicate <true/false>         keep only alignments that are\n\n                                    marked as duplicate? [true]\n\n  -isFailedQC <true/false>          keep only alignments that\n\n                                    failed QC? [true]\n\n  -isFirstMate <true/false>         keep only alignments marked as\n\n                                    first mate? [true]\n\n  -isMapped <true/false>            keep only alignments that were\n\n                                    mapped? [true]\n\n  -isMateMapped <true/false>        keep only alignments with\n\n                                    mates that mapped [true]\n\n  -isMateReverseStrand <true/false> keep only alignments with mate\n\n                                    on reverese strand? [true]\n\n  -isPaired <true/false>            keep only alignments that were\n\n                                    sequenced as paired? [true]\n\n  -isPrimaryAlignment <true/false>  keep only alignments marked as\n\n                                    primary? [true]\n\n  -isProperPair <true/false>        keep only alignments that\n\n                                    passed PE resolution? [true]\n\n  -isReverseStrand <true/false>     keep only alignments on\n\n                                    reverse strand? [true]\n\n  -isSecondMate <true/false>        keep only alignments marked as\n\n                                    second mate? [true]\n\n  -isSingleton <true/false>         keep only singletons [true]\n\n\n\nHelp:\n\n  --help, -h                        shows this help text",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ShellCommandRequirement"
                }
            ],
            "hints": [
                {
                    "dockerPull": "reddylab/bamtools:2.2.3",
                    "class": "DockerRequirement"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-alignmentFlag"
                    },
                    "doc": "<int>\nkeep reads with this *exact*\nalignment flag (for more detailed queries, see below)\n",
                    "id": "#bamtools-filter.cwl/alignmentFlag"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-forceCompression"
                    },
                    "doc": "if results are sent to stdout\\n(like when piping to another tool),\ndefault behavior is to leave output\nuncompressed. Use this flag to override\nand force compression.\n",
                    "id": "#bamtools-filter.cwl/forceCompression"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-in"
                    },
                    "doc": "<BAM filename>\nthe input BAM file(s) [stdin if omitted]\n",
                    "id": "#bamtools-filter.cwl/in"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-insertSize"
                    },
                    "doc": "<int>\nkeep reads with insert size that matches pattern\n",
                    "id": "#bamtools-filter.cwl/insertSize"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-isDuplicate"
                    },
                    "doc": "<true/false>\nkeep only alignments that are marked as duplicate? [true]\n",
                    "id": "#bamtools-filter.cwl/isDuplicate"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-isFailedQC"
                    },
                    "doc": "<true/false>          keep only alignments that\nfailed QC? [true]\n",
                    "id": "#bamtools-filter.cwl/isFailedQC"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-isFirstMate"
                    },
                    "doc": "<true/false>         keep only alignments marked as\nfirst mate? [true]\n",
                    "id": "#bamtools-filter.cwl/isFirstMate"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-isMapped"
                    },
                    "doc": "<true/false>            keep only alignments that were\nmapped? [true]\n",
                    "id": "#bamtools-filter.cwl/isMapped"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-isMateMapped"
                    },
                    "doc": "<true/false>        keep only alignments with\nmates that mapped [true]\n",
                    "id": "#bamtools-filter.cwl/isMateMapped"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-isMateReverseStrand"
                    },
                    "doc": "<true/false> keep only alignments with mate\non reverese strand? [true]\n",
                    "id": "#bamtools-filter.cwl/isMateReverseStrand"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-isPaired"
                    },
                    "doc": "<true/false>            keep only alignments that were\nsequenced as paired? [true]\n",
                    "id": "#bamtools-filter.cwl/isPaired"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-isPrimaryAlignment"
                    },
                    "doc": "<true/false>  keep only alignments marked as\nprimary? [true]\n",
                    "id": "#bamtools-filter.cwl/isPrimaryAlignment"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-isProperPair"
                    },
                    "doc": "<true/false>        keep only alignments that\npassed PE resolution? [true]\n",
                    "id": "#bamtools-filter.cwl/isProperPair"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-isReverseStrand"
                    },
                    "doc": "<true/false>     keep only alignments on\nreverse strand? [true]\n",
                    "id": "#bamtools-filter.cwl/isReverseStrand"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-isSecondMate"
                    },
                    "doc": "<true/false>        keep only alignments marked as\nsecond mate? [true]\n",
                    "id": "#bamtools-filter.cwl/isSecondMate"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-isSingleton"
                    },
                    "doc": "<true/false>         keep only singletons [true]\nHelp:\n--help, -h                        shows this help text\n",
                    "id": "#bamtools-filter.cwl/isSingleton"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-mapQuality"
                    },
                    "doc": "<[0-255]>\nkeep reads with map quality that matches pattern (e.g. '>50')\n",
                    "id": "#bamtools-filter.cwl/mapQuality"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-name"
                    },
                    "doc": "<string>\nkeep reads with name that matches pattern\n",
                    "id": "#bamtools-filter.cwl/name"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-out"
                    },
                    "doc": "<BAM filename>\nthe output BAM filename [stdout ]\n",
                    "id": "#bamtools-filter.cwl/out"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-queryBases"
                    },
                    "doc": "<string>\nkeep reads with motif that matches pattern\n",
                    "id": "#bamtools-filter.cwl/queryBases"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-region"
                    },
                    "doc": "<REGION>\nonly read data from this\ngenomic region (see documentation for more\ndetails)\n",
                    "id": "#bamtools-filter.cwl/region"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-script"
                    },
                    "doc": "<filename>\nthe filter script file (see documentation for more details)\n",
                    "id": "#bamtools-filter.cwl/script"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-tag"
                    },
                    "doc": "<TAG:VALUE>\nkeep reads with this key=>value pair\n",
                    "id": "#bamtools-filter.cwl/tag"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.out)"
                    },
                    "id": "#bamtools-filter.cwl/output_file"
                }
            ],
            "baseCommand": [
                "bamtools",
                "filter"
            ],
            "id": "#bamtools-filter.cwl"
        },
        {
            "class": "Workflow",
            "doc": "Split reads in a BAM file by strands and index forward and reverse output BAM files",
            "requirements": [
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "inputs": [
                {
                    "doc": "JSON filter file for forward strand used in bamtools (see bamtools-filter command)",
                    "type": "File",
                    "id": "#main/bamtools_forward_filter_file"
                },
                {
                    "doc": "JSON filter file for reverse strand used in bamtools (see bamtools-filter command)",
                    "type": "File",
                    "id": "#main/bamtools_reverse_filter_file"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#main/input_bam_files"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "id": "#main/input_basenames"
                }
            ],
            "steps": [
                {
                    "run": "#samtools-index.cwl",
                    "in": [
                        {
                            "source": "#main/split-bam-minus/output_file",
                            "id": "#main/index_minus_bam/input_file"
                        }
                    ],
                    "scatter": "#main/index_minus_bam/input_file",
                    "out": [
                        "#main/index_minus_bam/indexed_file"
                    ],
                    "id": "#main/index_minus_bam"
                },
                {
                    "run": "#samtools-index.cwl",
                    "scatter": "#main/index_plus_bam/input_file",
                    "in": [
                        {
                            "source": "#main/split-bam-plus/output_file",
                            "id": "#main/index_plus_bam/input_file"
                        }
                    ],
                    "out": [
                        "#main/index_plus_bam/indexed_file"
                    ],
                    "id": "#main/index_plus_bam"
                },
                {
                    "run": "#bamtools-filter.cwl",
                    "scatterMethod": "dotproduct",
                    "scatter": [
                        "#main/split-bam-minus/in",
                        "#main/split-bam-minus/out"
                    ],
                    "in": [
                        {
                            "source": "#main/input_bam_files",
                            "valueFrom": "${return [self]}",
                            "id": "#main/split-bam-minus/in"
                        },
                        {
                            "source": "#main/input_basenames",
                            "valueFrom": "$(self + \".Aligned.minus.bam\")",
                            "id": "#main/split-bam-minus/out"
                        },
                        {
                            "source": "#main/bamtools_reverse_filter_file",
                            "id": "#main/split-bam-minus/script"
                        }
                    ],
                    "out": [
                        "#main/split-bam-minus/output_file"
                    ],
                    "id": "#main/split-bam-minus"
                },
                {
                    "run": "#bamtools-filter.cwl",
                    "scatterMethod": "dotproduct",
                    "scatter": [
                        "#main/split-bam-plus/in",
                        "#main/split-bam-plus/out"
                    ],
                    "in": [
                        {
                            "source": "#main/input_bam_files",
                            "valueFrom": "${return [self]}",
                            "id": "#main/split-bam-plus/in"
                        },
                        {
                            "source": "#main/input_basenames",
                            "valueFrom": "$(self + \".Aligned.plus.bam\")",
                            "id": "#main/split-bam-plus/out"
                        },
                        {
                            "source": "#main/bamtools_forward_filter_file",
                            "id": "#main/split-bam-plus/script"
                        }
                    ],
                    "out": [
                        "#main/split-bam-plus/output_file"
                    ],
                    "id": "#main/split-bam-plus"
                }
            ],
            "outputs": [
                {
                    "doc": "BAM files containing only reads in the reverse (minus) strand.",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/index_minus_bam/indexed_file",
                    "id": "#main/bam_minus_files"
                },
                {
                    "doc": "BAM files containing only reads in the forward (plus) strand.",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/index_plus_bam/indexed_file",
                    "id": "#main/bam_plus_files"
                }
            ],
            "id": "#main"
        }
    ],
    "cwlVersion": "v1.0"
}
